import 'package:dio/dio.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/params/load_communities_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/services/communities_service.dart';
import 'package:syncrow_web/services/api/api_exception.dart';
import 'package:syncrow_web/services/api/http_service.dart';

class RemoteCommunitiesService implements CommunitiesService {
  const RemoteCommunitiesService(this._httpService);

  final HTTPService _httpService;

  static const _defaultErrorMessage = 'Failed to load communities';

  @override
  Future<List<CommunityModel>> getCommunity(LoadCommunitiesParam param) async {
    try {
      return _httpService.get(
        path: '/api/communities/',
        expectedResponseModel: (json) => (json as List<dynamic>)
            .map((e) => CommunityModel.fromJson(e as Map<String, dynamic>))
            .toList(),
      );
    } on DioException catch (e) {
      final message = e.response?.data as Map<String, dynamic>?;
      final error = message?['error'] as Map<String, dynamic>?;
      final errorMessage = error?['error'] as String? ?? '';
      throw APIException(errorMessage);
    } catch (e) {
      final formattedErrorMessage = [_defaultErrorMessage, '$e'].join(': ');
      throw APIException(formattedErrorMessage);
    }
  }
}
