import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/params/load_communities_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/services/communities_service.dart';
import 'package:syncrow_web/services/api/api_exception.dart';

part 'communities_event.dart';
part 'communities_state.dart';

class CommunitiesBloc extends Bloc<CommunitiesEvent, CommunitiesState> {
  CommunitiesBloc({
    required CommunitiesService communitiesService,
  })  : _communitiesService = communitiesService,
        super(const CommunitiesState()) {
    on<LoadCommunities>(_onLoadCommunities);
  }

  final CommunitiesService _communitiesService;

  Future<void> _onLoadCommunities(
    LoadCommunities event,
    Emitter<CommunitiesState> emit,
  ) async {
    try {
      emit(const CommunitiesState(status: CommunitiesStatus.loading));
      final communities = await _communitiesService.getCommunity(event.param);
      emit(
        CommunitiesState(
          status: CommunitiesStatus.success,
          communities: communities,
        ),
      );
    } on APIException catch (e) {
      emit(
        CommunitiesState(
          status: CommunitiesStatus.failure,
          errorMessage: e.message,
        ),
      );
    } catch (e) {
      emit(
        CommunitiesState(
          status: CommunitiesStatus.failure,
          errorMessage: e.toString(),
        ),
      );
    }
  }
}
